@@ -1,12 +1,14 @@
+"""celery.worker"""
 from carrot.connection import DjangoAMQPConnection
 from celery.messaging import TaskConsumer
 from celery.conf import DAEMON_CONCURRENCY, DAEMON_LOG_FILE
 from celery.conf import QUEUE_WAKEUP_AFTER, EMPTY_MSG_EMIT_EVERY
 from celery.log import setup_logger
 from celery.registry import tasks
-from celery.process import ProcessQueue
+from celery.datastructures import TaskProcessQueue
 from celery.models import PeriodicTaskMeta
 from celery.task import mark_as_done, mark_as_failure
+from celery.timer import EventTimer
 import multiprocessing
 import simplejson
 import traceback
@@ -24,18 +26,19 @@ class UnknownTask(Exception):
 
 
 def jail(task_id, callable_, args, kwargs):
+    """Wraps the task in a jail which saves the status and result
+    of the task execution to the task meta backend."""
     try:
         result = callable_(*args, **kwargs)
         mark_as_done(task_id, result)
-        print("SUCCESS: %s" % result)
         return result
     except Exception, exc:
         mark_as_failure(task_id, exc)
-        print("FAILURE: %s\n%s" % (exc, traceback.format_exc()))
         return exc
 
 
 class TaskWrapper(object):
+    """Class defining a task to be run."""
     def __init__(self, task_name, task_id, task_func, args, kwargs):
         self.task_name = task_name
         self.task_id = task_id
@@ -45,6 +48,8 @@ class TaskWrapper(object):
 
     @classmethod
     def from_message(cls, message):
+        """Create a TaskWrapper from a message returned by
+        :class:`celery.messaging.TaskConsumer`."""
         message_data = simplejson.loads(message.body)
         task_name = message_data["task"]
         task_id = message_data["id"]
@@ -57,6 +62,11 @@ class TaskWrapper(object):
         return cls(task_name, task_id, task_func, args, kwargs)
 
     def extend_kwargs_with_logging(self, loglevel, logfile):
+        """Extend the tasks keyword arguments with standard task arguments.
+
+        These are ``logfile``, ``loglevel``, ``task_id`` and ``task_name``.
+
+        """
         task_func_kwargs = {"logfile": logfile,
                             "loglevel": loglevel,
                             "task_id": self.task_id,
@@ -65,33 +75,19 @@ class TaskWrapper(object):
         return task_func_kwargs
 
     def execute(self, loglevel, logfile):
+        """Execute the task in a ``jail()`` and store its result and status
+        in the task meta backend."""
         task_func_kwargs = self.extend_kwargs_with_logging(loglevel, logfile)
         return jail(self.task_id, [
                         self.task_func, self.args, task_func_kwargs])
 
     def execute_using_pool(self, pool, loglevel, logfile):
+        """Like ``execute``, but using the ``multiprocessing`` pool."""
         task_func_kwargs = self.extend_kwargs_with_logging(loglevel, logfile)
         return pool.apply_async(jail, [self.task_id, self.task_func,
                                        self.args, task_func_kwargs])
 
 
-class EventTimer(object):
-    """Do something at an interval."""
-
-    def __init__(self, event, interval=None):
-        self.event = event
-        self.interval = interval
-        self.last_triggered = None
-
-    def tick(self):
-        if not self.interval: # never trigger if no interval.
-            return
-        if not self.last_triggered or \
-                time.time() > self.last_triggered + self.interval:
-            self.event()
-            self.last_triggered = time.time()
-
-
 class TaskDaemon(object):
     """Executes tasks waiting in the task queue.
 
@@ -164,7 +160,7 @@ class TaskDaemon(object):
 
     def run(self):
         """The worker server's main loop."""
-        results = ProcessQueue(self.concurrency, logger=self.logger,
+        results = TaskProcessQueue(self.concurrency, logger=self.logger,
                 done_msg="Task %(name)s[%(id)s] processed: %(return_value)s")
         log_wait = lambda: self.logger.info("Waiting for queue...")
         ev_msg_waiting = EventTimer(log_wait, self.empty_msg_emit_every)
